@@ -295,7 +295,8 @@ class Item(object):
     #_____________________________________________________________________________________
     def upload_file(self, body, key=None, metadata={}, headers={},
                     access_key=None, secret_key=None, queue_derive=True, 
-                    ignore_preexisting_bucket=False, verbose=False, debug=False):
+                    ignore_preexisting_bucket=False, verify=True, verbose=False,
+                    debug=False):
         """Upload a single file to an item. The item will be created
         if it does not exist.
 
@@ -347,17 +348,21 @@ class Item(object):
         except IOError:
             size = None
 
+        if not headers.get('x-archive-size-hint'):
+            headers['x-archive-size-hint'] = size
+
         key = body.name.split('/')[-1] if key is None else key
         url = 'http://s3.us.archive.org/{0}/{1}'.format(self.identifier, key) 
         headers = s3.build_headers(metadata=metadata, 
                                    headers=headers, 
                                    queue_derive=queue_derive,
                                    auto_make_bucket=True,
-                                   size_hint=size,
                                    ignore_preexisting_bucket=ignore_preexisting_bucket)
+        if verify:
+            headers['Content-MD5'] = utils.get_md5(body)
         if verbose:
             try:
-                chunk_size = 1024
+                chunk_size = 1048576
                 expected_size = size/chunk_size + 1
                 chunks = utils.chunk_generator(body, chunk_size)
                 progress_generator = progress.bar(chunks, expected_size=expected_size, 
